@@ -14,6 +14,7 @@
 
 import voluptuous as v
 
+from grafana_dashboards.schema.links import Links
 from grafana_dashboards.schema.row import Row
 from grafana_dashboards.schema.template import Template
 
@@ -21,11 +22,19 @@ from grafana_dashboards.schema.template import Template
 class Dashboard(object):
 
     def get_schema(self):
+
         dashboard = {
             v.Required('timezone', default='utc'): v.Any('browser', 'utc'),
             v.Required('title'): v.All(str, v.Length(min=1)),
             v.Optional('id'): int,
+            v.Optional('tags'): [v.Any(str, v.Length(min=1))],
+            v.Optional('time'): {
+                v.Required('from'): v.Any(v.Datetime(), str),
+                v.Required('to'): v.Any(v.Datetime(), str),
+            },
         }
+        links = Links().get_schema()
+        dashboard.update(links.schema)
         rows = Row().get_schema()
         dashboard.update(rows.schema)
         templating = Template().get_schema()
