@@ -23,8 +23,10 @@ class Datasource(object):
             v.Required('isDefault', default=False): v.All(bool),
             v.Required('name'): v.All(str, v.Length(min=1)),
             v.Required('type', default='graphite'): v.Any('graphite',
-                                                          'influxdb'),
+                                                          'influxdb',
+                                                          'prometheus'),
             v.Required('url'): v.All(str, v.Length(min=1)),
             v.Optional('orgId'): int,
+            v.Optional('database'): v.All(str, v.Length(min=1)),
         }
         return datasource
