@@ -22,83 +22,23 @@ from grafana_dashboards.schema.panel.base import Base
 class Graph(Base):
 
     def get_schema(self):
-        y_format = v.Any(
-            u'none',
-            u'short',
-            u'percent',
-            u'percentunit',
-            u'humidity',
-            u'ppm',
-            u'dB',
-            u'currencyUSD',
-            u'currencyGBP',
-            u'currencyEUR',
-            u'currencyJPY',
-            u'hertz',
-            u'ns',
-            u'µs',
-            u'ms',
-            u's',
-            u'm',
-            u'h',
-            u'd',
-            u'bits',
-            u'bytes',
-            u'kbytes',
-            u'mbytes',
-            u'gbytes',
-            u'decbits',
-            u'decbytes',
-            u'deckbytes',
-            u'decmbytes',
-            u'decgbytes',
-            u'pps',
-            u'bps',
-            u'Bps',
-            u'Kbits',
-            u'KBs',
-            u'Mbits',
-            u'MBs',
-            u'GBs',
-            u'Gbits',
-            u'ops',
-            u'rps',
-            u'wps',
-            u'iops',
-            u'opm',
-            u'rpm',
-            u'wpm',
-            u'lengthmm',
-            u'lengthm',
-            u'lengthkm',
-            u'lengthmi',
-            u'velocityms',
-            u'velocitykmh',
-            u'velocitymph',
-            u'velocityknot',
-            u'mlitre',
-            u'litre',
-            u'm3',
-            u'watt',
-            u'kwatt',
-            u'watth',
-            u'kwatth',
-            u'joule',
-            u'ev',
-            u'amp',
-            u'volt',
-            u'celsius',
-            u'farenheit',
-            u'kelvin',
-            u'pressurembar',
-            u'pressurehpa',
-            u'pressurehg',
-            u'pressurepsi',
-        )
+
+        alert_format = {
+            # could enforce "evaulator"/"operator"/"query" on this...
+            v.Required('conditions'): v.All(list),
+            v.Required('frequency', default='60s'): v.All(str),
+            v.Required('name'): v.All(str),
+            v.Required('executionErrorState', default='alerting'): (
+                v.Any('alerting', 'keep_state')),
+            v.Required('noDataState', default='no_data'): (
+                v.Any('no_data', 'alerting', 'ok', 'keep_state')),
+            v.Optional('notifications', default=[]): v.All(list),
+        }
+
         yaxes_format = [
             {
                 v.Optional('decimals'): v.All(int),
-                v.Optional('format', default='short'): y_format,
+                v.Optional('format', default='short'): Base.formats,
                 v.Optional('label', default=''): v.All(str),
                 v.Optional('logBase', default=1): v.All(int, v.Range(min=1)),
                 v.Optional('max'): v.All(int),
@@ -126,6 +66,7 @@ class Graph(Base):
             v.Required('query_as_alias', default=True): v.All(bool),
             v.Required('shared', default=True): v.All(bool),
             v.Required('value_type', default='cumulative'): v.All(value_types),
+            v.Optional('sort'): v.Range(min=0, max=2),
         }
 
         series_override = {
@@ -149,6 +90,7 @@ class Graph(Base):
         series_overrides = [series_override]
 
         graph = {
+            v.Optional('alert'): v.All(alert_format),
             v.Required('bars', default=False): v.All(bool),
             v.Optional('datasource'): v.All(str),
             v.Optional('decimals'): v.All(int),
@@ -175,7 +117,8 @@ class Graph(Base):
             v.Optional('tooltip'): v.All(tooltip),
             v.Required('x-axis', default=True): v.All(bool),
             v.Required('y-axis', default=True): v.All(bool),
-            v.Optional('y_formats'): v.All([y_format], v.Length(min=2, max=2)),
+            v.Optional('y_formats'): v.All([Base.formats],
+                                           v.Length(min=2, max=2)),
             v.Optional('yaxes'): v.All(yaxes_format, v.Length(min=2, max=2)),
         }
         graph.update(self.base)
