@@ -39,6 +39,26 @@ class Singlestat(Base):
             v.Required('show', default=False): v.All(bool),
         }
 
+        gauge = {
+            v.Required('maxValue'): v.All(int),
+            v.Required('minValue'): v.Any(int),
+            v.Required('show', default=False): v.All(bool),
+            v.Required('thresholdLabels', default=False): v.All(bool),
+            v.Required('thresholdMarkers', default=False): v.All(bool),
+        }
+
+        valuemap = {
+            v.Required('op', default='='): v.Any(str),
+            v.Required('value'): v.Any(int),
+            v.Required('text'): v.Any(str)
+        }
+
+        rangemap = {
+            v.Required('from'): v.Any(int),
+            v.Required('to'): v.Any(int),
+            v.Required('text'): v.Any(str),
+        }
+
         singlestat = {
             v.Required('colorBackground', default=False): v.All(bool),
             v.Required('colorValue', default=False): v.All(bool),
@@ -61,12 +81,16 @@ class Singlestat(Base):
                 'valueFontSize', default='80%'): v.All(
                     v.Match(r'^[1-9]?[0]{1}%$|^1[0-9]?[0]{1}%$|^200%$')),
             v.Required('valueName', default='avg'): v.Any(
-                'avg', 'current', 'max', 'min', 'total'),
+                'min', 'max', 'avg', 'current', 'total',
+                'name', 'first', 'delta', 'diff', 'range', 'last_time'),
             v.Optional('datasource'): v.All(str),
             v.Optional('decimals'): v.All(int, v.Range(min=0, max=12)),
+            v.Optional('gauge'): gauge,
             v.Optional('hideTimeOverride'): v.All(bool),
             v.Optional('timeFrom'): v.All(v.Match(r'[1-9]+[0-9]*[smhdw]')),
             v.Optional('timeShift'): v.All(v.Match(r'[1-9]+[0-9]*[smhdw]')),
+            v.Optional('valueMaps'): v.All([valuemap]),
+            v.Optional('rangeMaps'): v.All([rangemap]),
         }
         singlestat.update(self.base)
         return v.Schema(singlestat)
