@@ -12,19 +12,29 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import logging
+
 import voluptuous as v
 
 from grafana_dashboards.schema.template.base import Base
 
+LOG = logging.getLogger(__name__)
+
 
 class Query(Base):
 
+    def validate_refresh(self, data):
+        v.Schema(v.Any(v.All(int, v.Range(min=0, max=2)), bool))(data)
+        if isinstance(data, bool):
+            LOG.warn('templating query refresh type bool is deprecated')
+        return data
+
     def get_schema(self):
         query = {
             v.Required('includeAll', default=False): v.All(bool),
             v.Required('multi', default=False): v.All(bool),
             v.Required('query', default=''): v.All(str),
-            v.Required('refresh', default=False): v.All(bool),
+            v.Required('refresh', default=0): self.validate_refresh,
             v.Optional('datasource'): v.All(str),
             v.Optional('hide'): v.All(int, v.Range(min=0, max=2)),
         }
